@@ -52,8 +52,8 @@ from functools import reduce
 from itertools import chain
 from pickle import PicklingError  # nosec
 
+import django
 from django import forms
-from django.contrib.admin.utils import lookup_needs_distinct
 from django.contrib.admin.widgets import SELECT2_TRANSLATIONS
 from django.core import signing
 from django.db.models import Q
@@ -64,6 +64,11 @@ from django.utils.translation import get_language
 from .cache import cache
 from .conf import settings
 
+if django.VERSION < (4, 0):
+    from django.contrib.admin.utils import lookup_needs_distinct as lookup_spawns_duplicates
+else:
+    from django.contrib.admin.utils import lookup_spawns_duplicates
+
 
 class Select2Mixin:
     """
@@ -85,6 +90,7 @@ class Select2Mixin:
         default_attrs = {
             "lang": self.i18n_name,
             "data-minimum-input-length": 0,
+            "data-theme": settings.SELECT2_THEME,
         }
         if self.is_required:
             default_attrs["data-allow-clear"] = "false"
@@ -115,18 +121,19 @@ class Select2Mixin:
         .. Note:: For more information visit
             https://docs.djangoproject.com/en/stable/topics/forms/media/#media-as-a-dynamic-property
         """
-        select2_js = (settings.SELECT2_JS,) if settings.SELECT2_JS else ()
-        select2_css = (settings.SELECT2_CSS,) if settings.SELECT2_CSS else ()
+        select2_js = [settings.SELECT2_JS] if settings.SELECT2_JS else []
+        select2_css = settings.SELECT2_CSS if settings.SELECT2_CSS else []
 
-        i18n_file = ()
+        if isinstance(select2_css, str):
+            select2_css = [select2_css]
+
+        i18n_file = []
         if self.i18n_name in settings.SELECT2_I18N_AVAILABLE_LANGUAGES:
-            i18n_file = (
-                ("%s/%s.js" % (settings.SELECT2_I18N_PATH, self.i18n_name),)
-            )
+            i18n_file = [f"{settings.SELECT2_I18N_PATH}/{self.i18n_name}.js"]
 
         return forms.Media(
-            js=select2_js + i18n_file + ("django_select2/django_select2.js",),
-            css={"screen": select2_css + ("django_select2/django_select2.css",)},
+            js=select2_js + i18n_file + ["django_select2/django_select2.js"],
+            css={"screen": select2_css + ["django_select2/django_select2.css"]},
         )
 
 
@@ -407,7 +414,7 @@ class ModelSelect2Mixin:
             or_queries = [Q(**{orm_lookup: term}) for orm_lookup in search_fields]
             select |= reduce(operator.or_, or_queries)
             use_distinct |= any(
-                lookup_needs_distinct(queryset.model._meta, search_spec)
+                lookup_spawns_duplicates(queryset.model._meta, search_spec)
                 for search_spec in search_fields
             )
 
@@ -415,7 +422,7 @@ class ModelSelect2Mixin:
             select &= Q(**dependent_fields)
 
         use_distinct |= any(
-            lookup_needs_distinct(queryset.model._meta, search_spec)
+            lookup_spawns_duplicates(queryset.model._meta, search_spec)
             for search_spec in dependent_fields.keys()
         )
 
